==> haskell-streaming-commons-0.2.3.0-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 streaming-commons
version:              0.2.3.0
visibility:           public
id:                   streaming-commons-0.2.3.0-HOO6VAoL4fF5cLmwP24GsY
key:                  streaming-commons-0.2.3.0-HOO6VAoL4fF5cLmwP24GsY
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  86318e41b5d7c29414ab31c9d793d0c6
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-streaming-commons
hs-libraries:         HSstreaming-commons-0.2.3.0-HOO6VAoL4fF5cLmwP24GsY
depends:
    array-0.5.4.0 async-2.2.5-1z0oB69LG2FBRno1il1zoZ base-4.17.2.1
    bytestring-0.11.5.3 directory-1.3.7.1
    network-3.1.4.0-ItBhIFDvz12FCCKfYobIMX process-1.6.18.0
    random-1.2.1.3-1epqCSzcS4p5bPWcI4Ab0S stm-2.5.1.0 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3 zlib-0.7.0.0-91jlV9oVAmRK4kV4PuEmaG

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.2.3.0-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 streaming-commons
version:              0.2.3.0
visibility:           public
id:                   streaming-commons-0.2.3.0-H0wQA0dmyBvJFx98LJ5Hhq
key:                  streaming-commons-0.2.3.0-H0wQA0dmyBvJFx98LJ5Hhq
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  8cd0115e2bdb57905fd31755834b948d
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/streaming-commons-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-streaming-commons
hs-libraries:         HSstreaming-commons-0.2.3.0-H0wQA0dmyBvJFx98LJ5Hhq
depends:
    array-0.5.4.0 async-2.2.5-8qrDbV8xcFXEsDmo0VTM7z base-4.17.2.1
    bytestring-0.11.5.3 directory-1.3.7.1
    network-3.1.4.0-AsoxBmMP1pfJSzv0IgKvnl process-1.6.18.0
    random-1.2.1.3-9I8x2ZdyyN6LUBxcAUCXuW stm-2.5.1.0 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3 zlib-0.7.0.0-Cp5NrmIK6SOKeEUrlvcsoq

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
